aboutsummaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/exchange/taler-exchange-httpd.c')
-rw-r--r--src/exchange/taler-exchange-httpd.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/exchange/taler-exchange-httpd.c b/src/exchange/taler-exchange-httpd.c
index 25af862b6..dfdf3546d 100644
--- a/src/exchange/taler-exchange-httpd.c
+++ b/src/exchange/taler-exchange-httpd.c
@@ -161,9 +161,9 @@ char *TEH_currency;
char *TEH_kyc_aml_trigger;
/**
* Option set to #GNUNET_YES if tipping is enabled.
*/
-int TEH_enable_tipping;
+int TEH_enable_rewards;
/**
* What is the largest amount we allow a peer to
@@ -1943,15 +1943,15 @@ exchange_serve_process_config (void)
"Amount in section `exchange' under `AML_THRESHOLD' uses the wrong currency!\n");
return GNUNET_SYSERR;
}
- TEH_enable_tipping
+ TEH_enable_rewards
= GNUNET_CONFIGURATION_get_value_yesno (
TEH_cfg,
"exchange",
- "ENABLE_TIPPING");
- if (GNUNET_SYSERR == TEH_enable_tipping)
+ "ENABLE_REWARDS");
+ if (GNUNET_SYSERR == TEH_enable_rewards)
{
GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
- "Need YES or NO in section `exchange' under `ENABLE_TIPPING'\n");
+ "Need YES or NO in section `exchange' under `ENABLE_REWARDS'\n");
return GNUNET_SYSERR;
}
if (GNUNET_OK !=
@@ -161,9 +161,9 @@ char *TEH_currency;
char *TEH_kyc_aml_trigger;
/**
- * Option set to #GNUNET_YES if tipping is enabled.
+ * Option set to #GNUNET_YES if rewards are enabled.
*/